@@ -1,5 +1,3 @@
-import k4a_module
-
 from .calibration import Calibration, CalibrationType
 from .capture import PyK4ACapture
 from .config import (
@@ -13,6 +11,7 @@ from .config import (
     WiredSyncMode,
 )
 from .errors import K4AException, K4ATimeoutException
+from .module import k4a_module
 from .playback import PyK4APlayback, SeekOrigin
 from .pyk4a import ColorControlCapabilities, PyK4A
 from .record import PyK4ARecord
